@@ -6,7 +6,13 @@
 #include "mvp/libmvp.h"
 
 extern mvpinit_t  MediamvpSetup;
-
+extern int        c_screen_width;
+extern int        c_screen_depth;
+extern int        c_gui_width;
+extern int        c_gui_depth;
+extern int        c_screensaver;
+extern char      *c_font_file;
+extern int        c_standard_switch;
 
 class cMediamvpMenuSetupPage: public cMenuSetupPage {
 private:
