@@ -437,6 +437,68 @@ void window_set_zorder(window_t *window, int z)
 	window_mark_dirty(window->parent);
 }
 
+/* Return the z-order of the first child */
+int window_get_back_zorder(window_t *window)
+{
+	if( ! window) {
+		return 0;
+	}
+
+	if(! window->parent) {
+		return 0;
+	}
+
+	return window_get_zorder(window->parent->first_child);
+}
+
+/* Return the z-order of the last child */
+int window_get_front_zorder(window_t *window)
+{
+	int zorder = 0;
+	window_t *current;
+
+	if(! window) {
+		return 0;
+	}
+
+	if(! window->parent) {
+		return 0;
+	}
+
+	current = window->parent->first_child;
+
+	while(current)
+	{
+		zorder = window_get_zorder(current);
+		current = current->next_sibling;
+	}
+
+	return zorder;
+}
+
+void window_bring_forward(window_t *window)
+{
+	int zorder = 0;
+	if( !window ) {
+		return;
+	}
+
+	zorder = window_get_front_zorder(window);
+	window_set_zorder(window, zorder + 1);
+}
+
+void window_send_backward(window_t *window)
+{
+	int zorder = 0;
+
+	if(! window) {
+		return;
+	}
+
+	zorder = window_get_back_zorder(window);
+	window_set_zorder(window, zorder - 1);
+}
+
 void window_add_child(window_t *parent, window_t *child)
 {
     window_t *current_window;
@@ -591,15 +653,16 @@ static void window_draw_internal(window_t *window, int *dirty)
 
     window_blit(window);
 
+    /* Draw any children */
+    if(window->first_child) {
+		window_draw_internal(window->first_child, dirty);
+    }
+
     /* Draw the next sibling */
     if(window->next_sibling) {
 		window_draw_internal(window->next_sibling, dirty);
     }
 
-    /* Draw any children */
-    if(window->first_child) {
-		window_draw_internal(window->first_child, dirty);
-    }
 }
 
 /* External function for drawing windows */
